showPaymentSelector method
Future<Map<String, dynamic> >
showPaymentSelector(
- PayProvider provider,
- List<
PaymentItem> paymentItems
Shows the payment selector to initiate a payment process.
This method wraps the showPaymentSelector method in the platform
interface, and opens the payment selector for the provider of choice,
with the paymentItems in the price summary.
Implementation
Future<Map<String, dynamic>> showPaymentSelector(
PayProvider provider,
List<PaymentItem> paymentItems,
) async {
await throwIfProviderIsNotDefined(provider);
return _payPlatform.showPaymentSelector(
_configurations[provider]!, paymentItems);
}